@@ -1,4 +1,4 @@
-/* $OpenBSD: cms_io.c,v 1.19 2023/04/26 14:23:18 tb Exp $ */
+/* $OpenBSD: cms_io.c,v 1.21 2024/03/30 01:53:05 joshua Exp $ */
 /*
  * Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project.
@@ -82,18 +82,21 @@ CMS_stream(unsigned char ***boundary, CMS_ContentInfo *cms)
 
 	return 1;
 }
+LCRYPTO_ALIAS(CMS_stream);
 
 CMS_ContentInfo *
 d2i_CMS_bio(BIO *bp, CMS_ContentInfo **cms)
 {
 	return ASN1_item_d2i_bio(&CMS_ContentInfo_it, bp, cms);
 }
+LCRYPTO_ALIAS(d2i_CMS_bio);
 
 int
 i2d_CMS_bio(BIO *bp, CMS_ContentInfo *cms)
 {
 	return ASN1_item_i2d_bio(&CMS_ContentInfo_it, bp, cms);
 }
+LCRYPTO_ALIAS(i2d_CMS_bio);
 
 
 CMS_ContentInfo *
@@ -102,6 +105,7 @@ PEM_read_bio_CMS(BIO *bp, CMS_ContentInfo **x, pem_password_cb *cb, void *u)
 	return PEM_ASN1_read_bio((d2i_of_void *)d2i_CMS_ContentInfo,
 	    PEM_STRING_CMS, bp, (void **)x, cb, u);
 }
+LCRYPTO_ALIAS(PEM_read_bio_CMS);
 
 CMS_ContentInfo *
 PEM_read_CMS(FILE *fp, CMS_ContentInfo **x, pem_password_cb *cb, void *u)
@@ -109,6 +113,7 @@ PEM_read_CMS(FILE *fp, CMS_ContentInfo **x, pem_password_cb *cb, void *u)
 	return PEM_ASN1_read((d2i_of_void *)d2i_CMS_ContentInfo,
 	    PEM_STRING_CMS, fp, (void **)x, cb, u);
 }
+LCRYPTO_ALIAS(PEM_read_CMS);
 
 int
 PEM_write_bio_CMS(BIO *bp, const CMS_ContentInfo *x)
@@ -116,6 +121,7 @@ PEM_write_bio_CMS(BIO *bp, const CMS_ContentInfo *x)
 	return PEM_ASN1_write_bio((i2d_of_void *)i2d_CMS_ContentInfo,
 	    PEM_STRING_CMS, bp, (void *)x, NULL, NULL, 0, NULL, NULL);
 }
+LCRYPTO_ALIAS(PEM_write_bio_CMS);
 
 int
 PEM_write_CMS(FILE *fp, const CMS_ContentInfo *x)
@@ -123,12 +129,14 @@ PEM_write_CMS(FILE *fp, const CMS_ContentInfo *x)
 	return PEM_ASN1_write((i2d_of_void *)i2d_CMS_ContentInfo,
 	    PEM_STRING_CMS, fp, (void *)x, NULL, NULL, 0, NULL, NULL);
 }
+LCRYPTO_ALIAS(PEM_write_CMS);
 
 BIO *
 BIO_new_CMS(BIO *out, CMS_ContentInfo *cms)
 {
 	return BIO_new_NDEF(out, (ASN1_VALUE *)cms, &CMS_ContentInfo_it);
 }
+LCRYPTO_ALIAS(BIO_new_CMS);
 
 /* CMS wrappers round generalised stream and MIME routines */
 
@@ -138,6 +146,7 @@ i2d_CMS_bio_stream(BIO *out, CMS_ContentInfo *cms, BIO *in, int flags)
 	return i2d_ASN1_bio_stream(out, (ASN1_VALUE *)cms, in, flags,
 	    &CMS_ContentInfo_it);
 }
+LCRYPTO_ALIAS(i2d_CMS_bio_stream);
 
 int
 PEM_write_bio_CMS_stream(BIO *out, CMS_ContentInfo *cms, BIO *in, int flags)
@@ -145,6 +154,7 @@ PEM_write_bio_CMS_stream(BIO *out, CMS_ContentInfo *cms, BIO *in, int flags)
 	return PEM_write_bio_ASN1_stream(out, (ASN1_VALUE *)cms, in, flags,
 	    "CMS", &CMS_ContentInfo_it);
 }
+LCRYPTO_ALIAS(PEM_write_bio_CMS_stream);
 
 int
 SMIME_write_CMS(BIO *bio, CMS_ContentInfo *cms, BIO *data, int flags)
@@ -159,6 +169,7 @@ SMIME_write_CMS(BIO *bio, CMS_ContentInfo *cms, BIO *data, int flags)
 	return SMIME_write_ASN1(bio, (ASN1_VALUE *)cms, data, flags, ctype_nid,
 	    econt_nid, mdalgs, &CMS_ContentInfo_it);
 }
+LCRYPTO_ALIAS(SMIME_write_CMS);
 
 CMS_ContentInfo *
 SMIME_read_CMS(BIO *bio, BIO **bcont)
@@ -166,3 +177,4 @@ SMIME_read_CMS(BIO *bio, BIO **bcont)
 	return (CMS_ContentInfo *)SMIME_read_ASN1(bio, bcont,
 	    &CMS_ContentInfo_it);
 }
+LCRYPTO_ALIAS(SMIME_read_CMS);
