@@ -1,4 +1,4 @@
-/*	$OpenBSD: crypto_init.c,v 1.8 2023/05/08 13:53:26 tb Exp $ */
+/*	$OpenBSD: crypto_init.c,v 1.22 2024/10/17 14:27:57 jsing Exp $ */
 /*
  * Copyright (c) 2018 Bob Beck <beck@openbsd.org>
  *
@@ -20,13 +20,14 @@
 #include <pthread.h>
 #include <stdio.h>
 
+#include <openssl/asn1.h>
 #include <openssl/conf.h>
-#include <openssl/engine.h>
 #include <openssl/err.h>
 #include <openssl/evp.h>
 #include <openssl/objects.h>
+#include <openssl/x509v3.h>
 
-#include "cryptlib.h"
+#include "crypto_internal.h"
 #include "x509_issuer_cache.h"
 
 int OpenSSL_config(const char *);
@@ -36,15 +37,20 @@ static pthread_once_t crypto_init_once = PTHREAD_ONCE_INIT;
 static pthread_t crypto_init_thread;
 static int crypto_init_cleaned_up;
 
+void
+OPENSSL_init(void)
+{
+}
+LCRYPTO_ALIAS(OPENSSL_init);
+
 static void
 OPENSSL_init_crypto_internal(void)
 {
 	crypto_init_thread = pthread_self();
 
-	OPENSSL_cpuid_setup();
+	crypto_cpu_caps_init();
+
 	ERR_load_crypto_strings();
-	OpenSSL_add_all_ciphers();
-	OpenSSL_add_all_digests();
 }
 
 int
@@ -71,6 +77,7 @@ OPENSSL_init_crypto(uint64_t opts, const void *settings)
 
 	return 1;
 }
+LCRYPTO_ALIAS(OPENSSL_init_crypto);
 
 void
 OPENSSL_cleanup(void)
@@ -79,9 +86,37 @@ OPENSSL_cleanup(void)
 	ERR_free_strings();
 
 	CRYPTO_cleanup_all_ex_data();
-	ENGINE_cleanup();
 	EVP_cleanup();
+
+	X509_VERIFY_PARAM_table_cleanup();
+
 	x509_issuer_cache_free();
 
 	crypto_init_cleaned_up = 1;
 }
+LCRYPTO_ALIAS(OPENSSL_cleanup);
+
+void
+OpenSSL_add_all_ciphers(void)
+{
+}
+LCRYPTO_ALIAS(OpenSSL_add_all_ciphers);
+
+void
+OpenSSL_add_all_digests(void)
+{
+}
+LCRYPTO_ALIAS(OpenSSL_add_all_digests);
+
+void
+OPENSSL_add_all_algorithms_noconf(void)
+{
+}
+LCRYPTO_ALIAS(OPENSSL_add_all_algorithms_noconf);
+
+void
+OPENSSL_add_all_algorithms_conf(void)
+{
+	OPENSSL_config(NULL);
+}
+LCRYPTO_ALIAS(OPENSSL_add_all_algorithms_conf);
