@@ -1,4 +1,4 @@
-/* $OpenBSD: dh_lib.c,v 1.45 2024/03/27 01:26:30 tb Exp $ */
+/* $OpenBSD: dh_lib.c,v 1.46 2024/11/29 15:59:57 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -154,11 +154,8 @@ DH_free(DH *dh)
 	CRYPTO_free_ex_data(CRYPTO_EX_INDEX_DH, dh, &dh->ex_data);
 
 	BN_free(dh->p);
-	BN_free(dh->g);
 	BN_free(dh->q);
-	BN_free(dh->j);
-	free(dh->seed);
-	BN_free(dh->counter);
+	BN_free(dh->g);
 	BN_free(dh->pub_key);
 	BN_free(dh->priv_key);
 	free(dh);
