@@ -1,4 +1,4 @@
-/* $OpenBSD: pk7_lib.c,v 1.28 2023/11/09 19:08:07 tb Exp $ */
+/* $OpenBSD: pk7_lib.c,v 1.30 2024/12/06 07:10:20 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -70,13 +70,17 @@ long
 PKCS7_ctrl(PKCS7 *p7, int cmd, long larg, char *parg)
 {
 	int nid;
-	long ret;
+	long ret = 0;
 
 	nid = OBJ_obj2nid(p7->type);
 
 	switch (cmd) {
 	case PKCS7_OP_SET_DETACHED_SIGNATURE:
 		if (nid == NID_pkcs7_signed) {
+			if (p7->d.sign == NULL) {
+				PKCS7error(PKCS7_R_NO_CONTENT);
+				break;
+			}
 			ret = p7->detached = (int)larg;
 			if (ret && PKCS7_type_is_data(p7->d.sign->contents)) {
 				ASN1_OCTET_STRING *os;
@@ -91,7 +95,8 @@ PKCS7_ctrl(PKCS7 *p7, int cmd, long larg, char *parg)
 		break;
 	case PKCS7_OP_GET_DETACHED_SIGNATURE:
 		if (nid == NID_pkcs7_signed) {
-			if (!p7->d.sign  || !p7->d.sign->contents->d.ptr)
+			if (p7->d.sign == NULL ||
+			    p7->d.sign->contents->d.ptr == NULL)
 				ret = 1;
 			else
 				ret = 0;
