@@ -1,4 +1,4 @@
-/* $OpenBSD: t1_lib.c,v 1.198 2023/11/18 10:51:09 tb Exp $ */
+/* $OpenBSD: t1_lib.c,v 1.204 2025/01/18 14:17:05 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -128,9 +128,9 @@ int
 tls1_new(SSL *s)
 {
 	if (!ssl3_new(s))
-		return (0);
+		return 0;
 	s->method->ssl_clear(s);
-	return (1);
+	return 1;
 }
 
 void
@@ -628,46 +628,31 @@ tls1_check_group(SSL *s, uint16_t group_id)
 static int
 tls1_set_ec_id(uint16_t *group_id, uint8_t *comp_id, EC_KEY *ec)
 {
-	const EC_GROUP *grp;
-	const EC_METHOD *meth;
-	int prime_field;
+	const EC_GROUP *group;
 	int nid;
 
-	if (ec == NULL)
-		return (0);
-
-	/* Determine whether the group is defined over a prime field. */
-	if ((grp = EC_KEY_get0_group(ec)) == NULL)
-		return (0);
-	if ((meth = EC_GROUP_method_of(grp)) == NULL)
-		return (0);
-	prime_field = (EC_METHOD_get_field_type(meth) == NID_X9_62_prime_field);
+	if ((group = EC_KEY_get0_group(ec)) == NULL)
+		return 0;
 
 	/* Determine group ID. */
-	nid = EC_GROUP_get_curve_name(grp);
-	/* If we have an ID set it, otherwise set arbitrary explicit group. */
+	nid = EC_GROUP_get_curve_name(group);
 	if (!tls1_ec_nid2group_id(nid, group_id))
-		*group_id = prime_field ? 0xff01 : 0xff02;
-
-	if (comp_id == NULL)
-		return (1);
+		return 0;
 
 	/* Specify the compression identifier. */
 	if (EC_KEY_get0_public_key(ec) == NULL)
-		return (0);
+		return 0;
 	*comp_id = TLSEXT_ECPOINTFORMAT_uncompressed;
 	if (EC_KEY_get_conv_form(ec) == POINT_CONVERSION_COMPRESSED) {
-		*comp_id = TLSEXT_ECPOINTFORMAT_ansiX962_compressed_char2;
-		if (prime_field)
-			*comp_id = TLSEXT_ECPOINTFORMAT_ansiX962_compressed_prime;
+		*comp_id = TLSEXT_ECPOINTFORMAT_ansiX962_compressed_prime;
 	}
 
-	return (1);
+	return 1;
 }
 
 /* Check that an EC key is compatible with extensions. */
 static int
-tls1_check_ec_key(SSL *s, const uint16_t *group_id, const uint8_t *comp_id)
+tls1_check_ec_key(SSL *s, const uint16_t group_id, const uint8_t comp_id)
 {
 	size_t groupslen, formatslen, i;
 	const uint16_t *groups;
@@ -678,29 +663,29 @@ tls1_check_ec_key(SSL *s, const uint16_t *group_id, const uint8_t *comp_id)
 	 * is supported (see RFC4492).
 	 */
 	tls1_get_formatlist(s, 1, &formats, &formatslen);
-	if (comp_id != NULL && formats != NULL) {
+	if (formats != NULL) {
 		for (i = 0; i < formatslen; i++) {
-			if (formats[i] == *comp_id)
+			if (formats[i] == comp_id)
 				break;
 		}
 		if (i == formatslen)
-			return (0);
+			return 0;
 	}
 
 	/*
 	 * Check group list if present, otherwise everything is supported.
 	 */
 	tls1_get_group_list(s, 1, &groups, &groupslen);
-	if (group_id != NULL && groups != NULL) {
+	if (groups != NULL) {
 		for (i = 0; i < groupslen; i++) {
-			if (groups[i] == *group_id)
+			if (groups[i] == group_id)
 				break;
 		}
 		if (i == groupslen)
-			return (0);
+			return 0;
 	}
 
-	return (1);
+	return 1;
 }
 
 /* Check EC server key is compatible with client extensions. */
@@ -714,15 +699,15 @@ tls1_check_ec_server_key(SSL *s)
 	EVP_PKEY *pkey;
 
 	if (cpk->x509 == NULL || cpk->privatekey == NULL)
-		return (0);
+		return 0;
 	if ((pkey = X509_get0_pubkey(cpk->x509)) == NULL)
-		return (0);
+		return 0;
 	if ((eckey = EVP_PKEY_get0_EC_KEY(pkey)) == NULL)
-		return (0);
+		return 0;
 	if (!tls1_set_ec_id(&group_id, &comp_id, eckey))
-		return (0);
+		return 0;
 
-	return tls1_check_ec_key(s, &group_id, &comp_id);
+	return tls1_check_ec_key(s, group_id, comp_id);
 }
 
 int
