@@ -1,4 +1,4 @@
-/* crypto/des/destest.c */
+/*	$OpenBSD: destest.c,v 1.4 2018/07/17 17:06:49 tb Exp $	*/
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -734,7 +734,7 @@ plain[8+4], plain[8+5], plain[8+6], plain[8+7]);
 	printf("input word alignment test");
 	for (i=0; i<4; i++)
 		{
-		printf(" %d",i);
+		printf(" %u",i);
 		DES_ncbc_encrypt(&(cbc_out[i]),cbc_in,
 				 strlen((char *)cbc_data)+1,&ks,
 				 &cbc_iv,DES_ENCRYPT);
@@ -742,7 +742,7 @@ plain[8+4], plain[8+5], plain[8+6], plain[8+7]);
 	printf("\noutput word alignment test");
 	for (i=0; i<4; i++)
 		{
-		printf(" %d",i);
+		printf(" %u",i);
 		DES_ncbc_encrypt(cbc_out,&(cbc_in[i]),
 				 strlen((char *)cbc_data)+1,&ks,
 				 &cbc_iv,DES_ENCRYPT);
