@@ -1,5 +1,4 @@
-/*	$OpenBSD: ectest.c,v 1.19 2023/04/18 15:28:17 tb Exp $	*/
-/* crypto/ec/ectest.c */
+/*	$OpenBSD: ectest.c,v 1.35 2025/01/24 11:49:13 tb Exp $	*/
 /*
  * Originally written by Bodo Moeller for the OpenSSL project.
  */
@@ -76,9 +75,6 @@
 #include <time.h>
 
 #include <openssl/ec.h>
-#ifndef OPENSSL_NO_ENGINE
-#include <openssl/engine.h>
-#endif
 #include <openssl/err.h>
 #include <openssl/obj_mac.h>
 #include <openssl/objects.h>
@@ -92,30 +88,24 @@
 	exit(1); \
 } while (0)
 
-#define TIMING_BASE_PT 0
-#define TIMING_RAND_PT 1
-#define TIMING_SIMUL 2
-
-int EC_POINT_get_Jprojective_coordinates_GFp(const EC_GROUP *group,
-    const EC_POINT *point, BIGNUM *x, BIGNUM *y, BIGNUM *z, BN_CTX *ctx);
-
 /* test multiplication with group order, long and negative scalars */
 static void
-group_order_tests(EC_GROUP *group)
+group_order_tests(EC_GROUP *group, BN_CTX *ctx)
 {
 	BIGNUM *n1, *n2, *order;
 	EC_POINT *P = EC_POINT_new(group);
 	EC_POINT *Q = EC_POINT_new(group);
-	BN_CTX *ctx;
 
-	if ((ctx = BN_CTX_new()) == NULL)
+	if (P == NULL || Q == NULL)
 		ABORT;
 
-	if ((n1 = BN_new()) == NULL)
+	BN_CTX_start(ctx);
+
+	if ((n1 = BN_CTX_get(ctx)) == NULL)
 		ABORT;
-	if ((n2 = BN_new()) == NULL)
+	if ((n2 = BN_CTX_get(ctx)) == NULL)
 		ABORT;
-	if ((order = BN_new()) == NULL)
+	if ((order = BN_CTX_get(ctx)) == NULL)
 		ABORT;
 	fprintf(stdout, "verify group order ...");
 	fflush(stdout);
@@ -127,16 +117,13 @@ group_order_tests(EC_GROUP *group)
 		ABORT;
 	fprintf(stdout, ".");
 	fflush(stdout);
-	if (!EC_GROUP_precompute_mult(group, ctx))
-		ABORT;
 	if (!EC_POINT_mul(group, Q, order, NULL, NULL, ctx))
 		ABORT;
 	if (!EC_POINT_is_at_infinity(group, Q))
 		ABORT;
 	fprintf(stdout, " ok\n");
 	fprintf(stdout, "long/negative scalar tests ... ");
-	/* XXX - switch back to BN_one() after next bump. */
-	if (!BN_set_word(n1, 1))
+	if (!BN_one(n1))
 		ABORT;
 	/* n1 = 1 - order */
 	if (!BN_sub(n1, n1, order))
@@ -162,10 +149,7 @@ group_order_tests(EC_GROUP *group)
 	fprintf(stdout, "ok\n");
 	EC_POINT_free(P);
 	EC_POINT_free(Q);
-	BN_free(n1);
-	BN_free(n2);
-	BN_free(order);
-	BN_CTX_free(ctx);
+	BN_CTX_end(ctx);
 }
 
 static void
@@ -198,20 +182,13 @@ prime_field_tests(void)
 	if (!BN_hex2bn(&b, "1"))
 		ABORT;
 
-	group = EC_GROUP_new(EC_GFp_mont_method()); /* applications should use EC_GROUP_new_curve_GFp
-	                                             * so that the library gets to choose the EC_METHOD */
-	if (!group)
-		ABORT;
-
-	if (!EC_GROUP_set_curve(group, p, a, b, ctx))
+	if ((group = EC_GROUP_new_curve_GFp(p, a, b, ctx)) == NULL)
 		ABORT;
 
 	{
 		EC_GROUP *tmp;
-		tmp = EC_GROUP_new(EC_GROUP_method_of(group));
-		if (!tmp)
-			ABORT;
-		if (!EC_GROUP_copy(tmp, group))
+
+		if ((tmp = EC_GROUP_dup(group)) == NULL)
 			ABORT;
 		EC_GROUP_free(group);
 		group = tmp;
@@ -258,7 +235,7 @@ prime_field_tests(void)
 		ABORT;
 	if (!EC_POINT_set_compressed_coordinates(group, Q, x, 1, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, Q, ctx)) {
+	if (EC_POINT_is_on_curve(group, Q, ctx) <= 0) {
 		if (!EC_POINT_get_affine_coordinates(group, Q, x, y, ctx))
 			ABORT;
 		fprintf(stderr, "Point is not on curve: x = 0x");
@@ -270,18 +247,16 @@ prime_field_tests(void)
 	}
 
 	fprintf(stdout, "A cyclic subgroup:\n");
-	k = 100;
+	k = 0;
 	do {
-		if (k-- == 0)
-			ABORT;
-
+		fprintf(stderr, "     %d - ", k);
 		if (EC_POINT_is_at_infinity(group, P))
-			fprintf(stdout, "     point at infinity\n");
+			fprintf(stdout, "point at infinity\n");
 		else {
 			if (!EC_POINT_get_affine_coordinates(group, P, x, y, ctx))
 				ABORT;
 
-			fprintf(stdout, "     x = 0x");
+			fprintf(stdout, "x = 0x");
 			BN_print_fp(stdout, x);
 			fprintf(stdout, ", y = 0x");
 			BN_print_fp(stdout, y);
@@ -292,8 +267,15 @@ prime_field_tests(void)
 			ABORT;
 		if (!EC_POINT_add(group, P, P, Q, ctx))
 			ABORT;
+		if (k++ > 99)
+			ABORT;
 	} while (!EC_POINT_is_at_infinity(group, P));
 
+	if (k != 7) {
+		fprintf(stderr, "cycled in %d iterations, want 7\n", k);
+		ABORT;
+	}
+
 	if (!EC_POINT_add(group, P, Q, R, ctx))
 		ABORT;
 	if (!EC_POINT_is_at_infinity(group, P))
@@ -307,9 +289,10 @@ prime_field_tests(void)
 	if (0 != EC_POINT_cmp(group, P, Q, ctx))
 		ABORT;
 	fprintf(stdout, "Generator as octet string, compressed form:\n     ");
-	for (i = 0; i < len; i++) fprintf(stdout, "%02X", buf[i]);
+	for (i = 0; i < len; i++)
+		fprintf(stdout, "%02X", buf[i]);
 
-		len = EC_POINT_point2oct(group, Q, POINT_CONVERSION_UNCOMPRESSED, buf, sizeof buf, ctx);
+	len = EC_POINT_point2oct(group, Q, POINT_CONVERSION_UNCOMPRESSED, buf, sizeof buf, ctx);
 	if (len == 0)
 		ABORT;
 	if (!EC_POINT_oct2point(group, P, buf, len, ctx))
@@ -317,9 +300,10 @@ prime_field_tests(void)
 	if (0 != EC_POINT_cmp(group, P, Q, ctx))
 		ABORT;
 	fprintf(stdout, "\nGenerator as octet string, uncompressed form:\n     ");
-	for (i = 0; i < len; i++) fprintf(stdout, "%02X", buf[i]);
+	for (i = 0; i < len; i++)
+		fprintf(stdout, "%02X", buf[i]);
 
-		len = EC_POINT_point2oct(group, Q, POINT_CONVERSION_HYBRID, buf, sizeof buf, ctx);
+	len = EC_POINT_point2oct(group, Q, POINT_CONVERSION_HYBRID, buf, sizeof buf, ctx);
 	if (len == 0)
 		ABORT;
 	if (!EC_POINT_oct2point(group, P, buf, len, ctx))
@@ -329,14 +313,12 @@ prime_field_tests(void)
 	fprintf(stdout, "\nGenerator as octet string, hybrid form:\n     ");
 	for (i = 0; i < len; i++) fprintf(stdout, "%02X", buf[i]);
 
-		if (!EC_POINT_get_Jprojective_coordinates_GFp(group, R, x, y, z, ctx))
-			ABORT;
-	fprintf(stdout, "\nA representation of the inverse of that generator in\nJacobian projective coordinates:\n     X = 0x");
+	if (!EC_POINT_get_affine_coordinates(group, R, x, y, ctx))
+		ABORT;
+	fprintf(stdout, "\nThe inverse of that generator:\n     X = 0x");
 	BN_print_fp(stdout, x);
 	fprintf(stdout, ", Y = 0x");
 	BN_print_fp(stdout, y);
-	fprintf(stdout, ", Z = 0x");
-	BN_print_fp(stdout, z);
 	fprintf(stdout, "\n");
 
 	if (!EC_POINT_invert(group, P, ctx))
@@ -365,7 +347,7 @@ prime_field_tests(void)
 		ABORT;
 	if (!EC_POINT_set_affine_coordinates(group, P, x, y, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	if (!BN_hex2bn(&z, "0100000000000000000001F4C8F927AED3CA752257"))
 		ABORT;
@@ -390,13 +372,10 @@ prime_field_tests(void)
 		ABORT;
 	fprintf(stdout, " ok\n");
 
-	group_order_tests(group);
+	group_order_tests(group, ctx);
 
-	if (!(P_160 = EC_GROUP_new(EC_GROUP_method_of(group))))
+	if ((P_160 = EC_GROUP_dup(group)) == NULL)
 		ABORT;
-	if (!EC_GROUP_copy(P_160, group))
-		ABORT;
-
 
 	/* Curve P-192 (FIPS PUB 186-2, App. 6) */
 
@@ -415,7 +394,7 @@ prime_field_tests(void)
 		ABORT;
 	if (!EC_POINT_set_compressed_coordinates(group, P, x, 1, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	if (!BN_hex2bn(&z, "FFFFFFFFFFFFFFFFFFFFFFFF99DEF836146BC9B1B4D22831"))
 		ABORT;
@@ -440,13 +419,10 @@ prime_field_tests(void)
 		ABORT;
 	fprintf(stdout, " ok\n");
 
-	group_order_tests(group);
+	group_order_tests(group, ctx);
 
-	if (!(P_192 = EC_GROUP_new(EC_GROUP_method_of(group))))
+	if ((P_192 = EC_GROUP_dup(group)) == NULL)
 		ABORT;
-	if (!EC_GROUP_copy(P_192, group))
-		ABORT;
-
 
 	/* Curve P-224 (FIPS PUB 186-2, App. 6) */
 
@@ -465,7 +441,7 @@ prime_field_tests(void)
 		ABORT;
 	if (!EC_POINT_set_compressed_coordinates(group, P, x, 0, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	if (!BN_hex2bn(&z, "FFFFFFFFFFFFFFFFFFFFFFFFFFFF16A2E0B8F03E13DD29455C5C2A3D"))
 		ABORT;
@@ -490,13 +466,10 @@ prime_field_tests(void)
 		ABORT;
 	fprintf(stdout, " ok\n");
 
-	group_order_tests(group);
+	group_order_tests(group, ctx);
 
-	if (!(P_224 = EC_GROUP_new(EC_GROUP_method_of(group))))
+	if ((P_224 = EC_GROUP_dup(group)) == NULL)
 		ABORT;
-	if (!EC_GROUP_copy(P_224, group))
-		ABORT;
-
 
 	/* Curve P-256 (FIPS PUB 186-2, App. 6) */
 
@@ -515,7 +488,7 @@ prime_field_tests(void)
 		ABORT;
 	if (!EC_POINT_set_compressed_coordinates(group, P, x, 1, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	if (!BN_hex2bn(&z, "FFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E"
 	    "84F3B9CAC2FC632551")) ABORT;
@@ -540,13 +513,10 @@ prime_field_tests(void)
 		ABORT;
 	fprintf(stdout, " ok\n");
 
-	group_order_tests(group);
+	group_order_tests(group, ctx);
 
-	if (!(P_256 = EC_GROUP_new(EC_GROUP_method_of(group))))
+	if ((P_256 = EC_GROUP_dup(group)) == NULL)
 		ABORT;
-	if (!EC_GROUP_copy(P_256, group))
-		ABORT;
-
 
 	/* Curve P-384 (FIPS PUB 186-2, App. 6) */
 
@@ -565,7 +535,7 @@ prime_field_tests(void)
 	    "9859F741E082542A385502F25DBF55296C3A545E3872760AB7")) ABORT;
 	if (!EC_POINT_set_compressed_coordinates(group, P, x, 1, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	if (!BN_hex2bn(&z, "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF"
 	    "FFC7634D81F4372DDF581A0DB248B0A77AECEC196ACCC52973")) ABORT;
@@ -590,13 +560,10 @@ prime_field_tests(void)
 		ABORT;
 	fprintf(stdout, " ok\n");
 
-	group_order_tests(group);
+	group_order_tests(group, ctx);
 
-	if (!(P_384 = EC_GROUP_new(EC_GROUP_method_of(group))))
+	if ((P_384 = EC_GROUP_dup(group)) == NULL)
 		ABORT;
-	if (!EC_GROUP_copy(P_384, group))
-		ABORT;
-
 
 	/* Curve P-521 (FIPS PUB 186-2, App. 6) */
 
@@ -619,7 +586,7 @@ prime_field_tests(void)
 	    "3C1856A429BF97E7E31C2E5BD66")) ABORT;
 	if (!EC_POINT_set_compressed_coordinates(group, P, x, 0, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	if (!BN_hex2bn(&z, "1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF"
 	    "FFFFFFFFFFFFFFFFFFFFA51868783BF2F966B7FCC0148F709A5D03BB5"
@@ -646,13 +613,10 @@ prime_field_tests(void)
 		ABORT;
 	fprintf(stdout, " ok\n");
 
-	group_order_tests(group);
+	group_order_tests(group, ctx);
 
-	if (!(P_521 = EC_GROUP_new(EC_GROUP_method_of(group))))
+	if ((P_521 = EC_GROUP_dup(group)) == NULL)
 		ABORT;
-	if (!EC_GROUP_copy(P_521, group))
-		ABORT;
-
 
 	/* more tests using the last curve */
 	fprintf(stdout, "infinity tests ...");
@@ -664,7 +628,7 @@ prime_field_tests(void)
 	/* P := 2P */
 	if (!EC_POINT_dbl(group, P, P, ctx))
 		ABORT;
-	if (!EC_POINT_is_on_curve(group, P, ctx))
+	if (EC_POINT_is_on_curve(group, P, ctx) <= 0)
 		ABORT;
 	/* Q := -P */
 	if (!EC_POINT_invert(group, Q, ctx))
@@ -692,72 +656,12 @@ prime_field_tests(void)
 	BN_free(y);
 	BN_free(z);
 
-	if (P_160)
-		EC_GROUP_free(P_160);
-	if (P_192)
-		EC_GROUP_free(P_192);
-	if (P_224)
-		EC_GROUP_free(P_224);
-	if (P_256)
-		EC_GROUP_free(P_256);
-	if (P_384)
-		EC_GROUP_free(P_384);
-	if (P_521)
-		EC_GROUP_free(P_521);
-
-}
-
-static void
-internal_curve_test(void)
-{
-	EC_builtin_curve *curves = NULL;
-	size_t crv_len = 0, n = 0;
-	int    ok = 1;
-
-	crv_len = EC_get_builtin_curves(NULL, 0);
-
-	curves = reallocarray(NULL, sizeof(EC_builtin_curve),  crv_len);
-
-	if (curves == NULL)
-		return;
-
-	if (!EC_get_builtin_curves(curves, crv_len)) {
-		free(curves);
-		return;
-	}
-
-	fprintf(stdout, "testing internal curves: ");
-
-	for (n = 0; n < crv_len; n++) {
-		EC_GROUP *group = NULL;
-		int nid = curves[n].nid;
-		if ((group = EC_GROUP_new_by_curve_name(nid)) == NULL) {
-			ok = 0;
-			fprintf(stdout, "\nEC_GROUP_new_curve_name() failed with"
-			    " curve %s\n", OBJ_nid2sn(nid));
-			/* try next curve */
-			continue;
-		}
-		if (!EC_GROUP_check(group, NULL)) {
-			ok = 0;
-			fprintf(stdout, "\nEC_GROUP_check() failed with"
-			    " curve %s\n", OBJ_nid2sn(nid));
-			EC_GROUP_free(group);
-			/* try the next curve */
-			continue;
-		}
-		fprintf(stdout, ".");
-		fflush(stdout);
-		EC_GROUP_free(group);
-	}
-	if (ok)
-		fprintf(stdout, " ok\n\n");
-	else {
-		fprintf(stdout, " failed\n\n");
-		ABORT;
-	}
-	free(curves);
-	return;
+	EC_GROUP_free(P_160);
+	EC_GROUP_free(P_192);
+	EC_GROUP_free(P_224);
+	EC_GROUP_free(P_256);
+	EC_GROUP_free(P_384);
+	EC_GROUP_free(P_521);
 }
 
 int
@@ -766,17 +670,10 @@ main(int argc, char *argv[])
 	ERR_load_crypto_strings();
 
 	prime_field_tests();
-	puts("");
-	/* test the internal curves */
-	internal_curve_test();
 
-#ifndef OPENSSL_NO_ENGINE
-	ENGINE_cleanup();
-#endif
 	CRYPTO_cleanup_all_ex_data();
 	ERR_free_strings();
 	ERR_remove_thread_state(NULL);
-	CRYPTO_mem_leaks_fp(stderr);
 
 	return 0;
 }
